==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QStatusTipEvent_shell.cpp <==
#include "QStatusTipEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QStatusTipEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStatusTipEvent")
    QStatusTipEvent *_ptr = reinterpret_cast<QStatusTipEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QStatusTipEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStatusTipEvent_shell) ); }

jmethodID QStatusTipEvent_shell::__shell_javaMethod(int pos) const { return QStatusTipEvent_shell::__shell()->javaMethod(typeid(QStatusTipEvent), pos); }

// emitting (writeShellConstructor)
QStatusTipEvent_shell::QStatusTipEvent_shell(const QStatusTipEvent& arg__1)
    : QStatusTipEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStatusTipEvent::QStatusTipEvent_shell(const QStatusTipEvent& arg__1)", QStatusTipEvent_shell::__shell())
    QStatusTipEvent_shell::__shell()->constructed(typeid(QStatusTipEvent));
}

QStatusTipEvent_shell::QStatusTipEvent_shell(const QString& tip0)
    : QStatusTipEvent(tip0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStatusTipEvent::QStatusTipEvent_shell(const QString& tip0)", QStatusTipEvent_shell::__shell())
    QStatusTipEvent_shell::__shell()->constructed(typeid(QStatusTipEvent));
}

// emitting (writeShellDestructor)
QStatusTipEvent_shell::~QStatusTipEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStatusTipEvent::~QStatusTipEvent()", QStatusTipEvent_shell::__shell())
    QStatusTipEvent_shell::__shell()->destructed(typeid(QStatusTipEvent));
}

void QStatusTipEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStatusTipEvent_shell*>(ptr)->QStatusTipEvent_shell::__shell()->tryDeleteShell(typeid(QStatusTipEvent));
}

// emitting Virtual overrides (virtualFunctions)
QStatusTipEvent* QStatusTipEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QStatusTipEvent::clone()const", QStatusTipEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QStatusTipEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QStatusTipEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QStatusTipEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QStatusTipEvent_shell::__shell()->warnForMethod("QStatusTipEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QStatusTipEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QStatusTipEvent::clone();
        }
    }else{
        return QStatusTipEvent::clone();
    }
}

void QStatusTipEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QStatusTipEvent::", QStatusTipEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QStatusTipEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QStatusTipEvent_shell::__shell()->warnForMethod("QStatusTipEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QStatusTipEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QStatusTipEvent_access::__qt_assign_cref_QStatusTipEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QStatusTipEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QStatusTipEvent>(__jni_env, other0);
    QStatusTipEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QStatusTipEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QStatusTipEvent* __qt_return_value = QStatusTipEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QStatusTipEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QStatusTipEvent(QStatusTipEvent)
void __qt_construct_QStatusTipEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStatusTipEvent(QStatusTipEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QStatusTipEvent& __qt_arg__1 = qtjambi_cast<const QStatusTipEvent& >(__jni_env, arg__1);
    QStatusTipEvent *__qt_this = new(__qtjambi_ptr) QStatusTipEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QStatusTipEvent(QString)
void __qt_construct_QStatusTipEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStatusTipEvent(QString)")
    jstring tip0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_tip0 = qtjambi_cast<QString>(__jni_env, tip0);
    QStatusTipEvent *__qt_this = new(__qtjambi_ptr) QStatusTipEvent_shell(__qt_tip0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QStatusTipEvent_shell
void __qt_destruct_QStatusTipEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStatusTipEvent")
    reinterpret_cast<QStatusTipEvent_shell*>(ptr)->~QStatusTipEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStatusTipEvent::QStatusTipEvent(QStatusTipEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QStatusTipEvent_initialize_1native__Lio_qt_gui_QStatusTipEvent_2Lio_qt_gui_QStatusTipEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStatusTipEvent::QStatusTipEvent(QStatusTipEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStatusTipEvent_0, sizeof(QStatusTipEvent_shell), typeid(QStatusTipEvent), true, &deleter_QStatusTipEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStatusTipEvent::QStatusTipEvent(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QStatusTipEvent_initialize_1native__Lio_qt_gui_QStatusTipEvent_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring tip0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStatusTipEvent::QStatusTipEvent(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = tip0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStatusTipEvent_1, sizeof(QStatusTipEvent_shell), typeid(QStatusTipEvent), true, &deleter_QStatusTipEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStatusTipEvent::operator=(QStatusTipEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QStatusTipEvent_assign_1native_1cref_1QStatusTipEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStatusTipEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStatusTipEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStatusTipEvent::operator=(QStatusTipEvent)", __qt_this)
        static_cast<QStatusTipEvent_access*>(__qt_this)->__qt_assign_cref_QStatusTipEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStatusTipEvent::tip()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QStatusTipEvent_tip_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QStatusTipEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStatusTipEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStatusTipEvent::tip()const", __qt_this)
        QString __qt_return_value = __qt_this->tip();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStatusTipEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QStatusTipEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QStatusTipEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStatusTipEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStatusTipEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QStatusTipEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QStatusTipEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QStatusTipEvent>("QStatusTipEvent", "io/qt/gui/QStatusTipEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QStatusTipEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QStatusTipEvent, {
        ConstructorInfo(&__qt_construct_QStatusTipEvent_0, "Lio/qt/gui/QStatusTipEvent;")
       ,ConstructorInfo(&__qt_construct_QStatusTipEvent_1, "Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStatusTipEvent);
    registerSizeOfShell(typeId, sizeof(QStatusTipEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QStatusTipEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QStatusTipEvent_shell.cpp <==
#include "QStatusTipEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QStatusTipEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStatusTipEvent")
    QStatusTipEvent *_ptr = reinterpret_cast<QStatusTipEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QStatusTipEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStatusTipEvent_shell) ); }

jmethodID QStatusTipEvent_shell::__shell_javaMethod(int pos) const { return QStatusTipEvent_shell::__shell()->javaMethod(typeid(QStatusTipEvent), pos); }

// emitting (writeShellConstructor)
QStatusTipEvent_shell::QStatusTipEvent_shell(const QStatusTipEvent& arg__1)
    : QStatusTipEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStatusTipEvent::QStatusTipEvent_shell(const QStatusTipEvent& arg__1)", QStatusTipEvent_shell::__shell())
    QStatusTipEvent_shell::__shell()->constructed(typeid(QStatusTipEvent));
}

QStatusTipEvent_shell::QStatusTipEvent_shell(const QString& tip0)
    : QStatusTipEvent(tip0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStatusTipEvent::QStatusTipEvent_shell(const QString& tip0)", QStatusTipEvent_shell::__shell())
    QStatusTipEvent_shell::__shell()->constructed(typeid(QStatusTipEvent));
}

// emitting (writeShellDestructor)
QStatusTipEvent_shell::~QStatusTipEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStatusTipEvent::~QStatusTipEvent()", QStatusTipEvent_shell::__shell())
    QStatusTipEvent_shell::__shell()->destructed(typeid(QStatusTipEvent));
}

void QStatusTipEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStatusTipEvent_shell*>(ptr)->QStatusTipEvent_shell::__shell()->tryDeleteShell(typeid(QStatusTipEvent));
}

// emitting Virtual overrides (virtualFunctions)
QStatusTipEvent* QStatusTipEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QStatusTipEvent::clone()const", QStatusTipEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QStatusTipEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QStatusTipEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QStatusTipEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QStatusTipEvent_shell::__shell()->warnForMethod("QStatusTipEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QStatusTipEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QStatusTipEvent::clone();
        }
    }else{
        return QStatusTipEvent::clone();
    }
}

void QStatusTipEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QStatusTipEvent::", QStatusTipEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QStatusTipEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QStatusTipEvent_shell::__shell()->warnForMethod("QStatusTipEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QStatusTipEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QStatusTipEvent_access::__qt_assign_cref_QStatusTipEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QStatusTipEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QStatusTipEvent>(__jni_env, other0);
    QStatusTipEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QStatusTipEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QStatusTipEvent* __qt_return_value = QStatusTipEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QStatusTipEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QStatusTipEvent(QStatusTipEvent)
void __qt_construct_QStatusTipEvent_cref_QStatusTipEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStatusTipEvent(QStatusTipEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QStatusTipEvent& __qt_arg__1 = qtjambi_cast<const QStatusTipEvent& >(__jni_env, arg__1);
    QStatusTipEvent *__qt_this = new(__qtjambi_ptr) QStatusTipEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStatusTipEvent::QStatusTipEvent(QStatusTipEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QStatusTipEvent_initialize_1native__Lio_qt_gui_QStatusTipEvent_2Lio_qt_gui_QStatusTipEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStatusTipEvent::QStatusTipEvent(QStatusTipEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStatusTipEvent_cref_QStatusTipEvent, sizeof(QStatusTipEvent_shell), typeid(QStatusTipEvent), true, &deleter_QStatusTipEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStatusTipEvent(QString)
void __qt_construct_QStatusTipEvent_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStatusTipEvent(QString)")
    jstring tip0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_tip0 = qtjambi_cast<QString>(__jni_env, tip0);
    QStatusTipEvent *__qt_this = new(__qtjambi_ptr) QStatusTipEvent_shell(__qt_tip0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStatusTipEvent::QStatusTipEvent(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QStatusTipEvent_initialize_1native__Lio_qt_gui_QStatusTipEvent_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring tip0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStatusTipEvent::QStatusTipEvent(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = tip0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStatusTipEvent_cref_QString, sizeof(QStatusTipEvent_shell), typeid(QStatusTipEvent), true, &deleter_QStatusTipEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStatusTipEvent_shell
void __qt_destruct_QStatusTipEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStatusTipEvent")
    reinterpret_cast<QStatusTipEvent_shell*>(ptr)->~QStatusTipEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStatusTipEvent::operator=(QStatusTipEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QStatusTipEvent_assign_1native_1cref_1QStatusTipEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStatusTipEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStatusTipEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStatusTipEvent::operator=(QStatusTipEvent)", __qt_this)
        static_cast<QStatusTipEvent_access*>(__qt_this)->__qt_assign_cref_QStatusTipEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStatusTipEvent::tip()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QStatusTipEvent_tip_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QStatusTipEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStatusTipEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStatusTipEvent::tip()const", __qt_this)
        QString __qt_return_value = __qt_this->tip();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStatusTipEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QStatusTipEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QStatusTipEvent *__qt_this = QtJambiAPI::objectFromNativeId<QStatusTipEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStatusTipEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QStatusTipEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QStatusTipEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QStatusTipEvent>("QStatusTipEvent", "io/qt/gui/QStatusTipEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QStatusTipEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QStatusTipEvent, {
        ConstructorInfo(&__qt_construct_QStatusTipEvent_cref_QStatusTipEvent, "Lio/qt/gui/QStatusTipEvent;")
       ,ConstructorInfo(&__qt_construct_QStatusTipEvent_cref_QString, "Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStatusTipEvent);
    registerSizeOfShell(typeId, sizeof(QStatusTipEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QStatusTipEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
